import OCP.HLRAlgo
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.gp
import OCP.TColgp
import OCP.Standard
import OCP.TopAbs
import OCP.NCollection
__all__  = [
"HLRAlgo",
"HLRAlgo_Array1OfPHDat",
"HLRAlgo_Array1OfPINod",
"HLRAlgo_Array1OfPISeg",
"HLRAlgo_Array1OfTData",
"HLRAlgo_BiPoint",
"HLRAlgo_Coincidence",
"HLRAlgo_EdgeIterator",
"HLRAlgo_EdgeStatus",
"HLRAlgo_EdgesBlock",
"HLRAlgo_HArray1OfPHDat",
"HLRAlgo_HArray1OfPINod",
"HLRAlgo_HArray1OfPISeg",
"HLRAlgo_HArray1OfTData",
"HLRAlgo_Interference",
"HLRAlgo_InterferenceList",
"HLRAlgo_Intersection",
"HLRAlgo_ListOfBPoint",
"HLRAlgo_PolyAlgo",
"HLRAlgo_PolyData",
"HLRAlgo_PolyHidingData",
"HLRAlgo_PolyInternalData",
"HLRAlgo_PolyInternalNode",
"HLRAlgo_PolyInternalSegment",
"HLRAlgo_PolyMask",
"HLRAlgo_PolyShellData",
"HLRAlgo_Projector",
"HLRAlgo_TriangleData",
"HLRAlgo_WiresBlock",
"HLRAlgo_PolyMask_EMskGrALin1",
"HLRAlgo_PolyMask_EMskGrALin2",
"HLRAlgo_PolyMask_EMskGrALin3",
"HLRAlgo_PolyMask_EMskOutLin1",
"HLRAlgo_PolyMask_EMskOutLin2",
"HLRAlgo_PolyMask_EMskOutLin3",
"HLRAlgo_PolyMask_FMskBack",
"HLRAlgo_PolyMask_FMskFlat",
"HLRAlgo_PolyMask_FMskFrBack",
"HLRAlgo_PolyMask_FMskHiding",
"HLRAlgo_PolyMask_FMskOnOutL",
"HLRAlgo_PolyMask_FMskOrBack",
"HLRAlgo_PolyMask_FMskSide"
]
class HLRAlgo():
    """
    In order to have the precision required in industrial design, drawings need to offer the possibility of removing lines, which are hidden in a given projection. To do this, the Hidden Line Removal component provides two algorithms: HLRBRep_Algo and HLRBRep_PolyAlgo. These algorithms remove or indicate lines hidden by surfaces. For a given projection, they calculate a set of lines characteristic of the object being represented. They are also used in conjunction with extraction utilities, which reconstruct a new, simplified shape from a selection of calculation results. This new shape is made up of edges, which represent the lines of the visualized shape in a plane. This plane is the projection plane. HLRBRep_Algo takes into account the shape itself. HLRBRep_PolyAlgo works with a polyhedral simplification of the shape. When you use HLRBRep_Algo, you obtain an exact result, whereas, when you use HLRBRep_PolyAlgo, you reduce computation time but obtain polygonal segments.
    """
    @staticmethod
    def AddMinMax_s(IMin : Any,IMax : Any,OMin : Any,OMax : Any) -> None: ...
    @staticmethod
    def CopyMinMax_s(IMin : Any,IMax : Any,OMin : Any,OMax : Any) -> None: ...
    @staticmethod
    def DecodeMinMax_s(MinMax : Any,Min : Any,Max : Any) -> None: ...
    @staticmethod
    def EncodeMinMax_s(Min : Any,Max : Any,MinMax : Any) -> None: ...
    @staticmethod
    def EnlargeMinMax_s(tol : float,Min : float,Max : float) -> None: ...
    @staticmethod
    def InitMinMax_s(Big : float,Min : float,Max : float) -> None: ...
    @staticmethod
    def SizeBox_s(Min : Any,Max : Any) -> float: ...
    @staticmethod
    def UpdateMinMax_s(x : float,y : float,z : float,Min : float,Max : float) -> None: 
        """
        Iterator on the visible or hidden parts of an EdgeStatus.
        """
    def __init__(self) -> None: ...
    pass
class HLRAlgo_Array1OfPHDat():
    """
    The class NCollection_Array1 represents unidimensional arrays of fixed size known at run time. The range of the index is user defined. An array1 can be constructed with a "C array". This functionality is useful to call methods expecting an Array1. It allows to carry the bounds inside the arrays.
    """
    def Assign(self,theOther : HLRAlgo_Array1OfPHDat) -> HLRAlgo_Array1OfPHDat: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeFirst(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_PolyHidingData: 
        """
        Variable value access
        """
    def First(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns first element
        """
    def Init(self,theValue : HLRAlgo_PolyHidingData) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    def Last(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfPHDat) -> HLRAlgo_Array1OfPHDat: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_PolyHidingData) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_PolyHidingData: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_PolyHidingData: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theAlloc : Any,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfPHDat) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_PolyHidingData]: ...
    def __len__(self) -> int: ...
    pass
class HLRAlgo_Array1OfPINod():
    """
    The class NCollection_Array1 represents unidimensional arrays of fixed size known at run time. The range of the index is user defined. An array1 can be constructed with a "C array". This functionality is useful to call methods expecting an Array1. It allows to carry the bounds inside the arrays.
    """
    def Assign(self,theOther : HLRAlgo_Array1OfPINod) -> HLRAlgo_Array1OfPINod: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeFirst(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_PolyInternalNode: 
        """
        Variable value access
        """
    def First(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns first element
        """
    def Init(self,theValue : HLRAlgo_PolyInternalNode) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    def Last(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfPINod) -> HLRAlgo_Array1OfPINod: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_PolyInternalNode) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_PolyInternalNode: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_PolyInternalNode: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theAlloc : Any,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfPINod) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_PolyInternalNode]: ...
    def __len__(self) -> int: ...
    pass
class HLRAlgo_Array1OfPISeg():
    """
    The class NCollection_Array1 represents unidimensional arrays of fixed size known at run time. The range of the index is user defined. An array1 can be constructed with a "C array". This functionality is useful to call methods expecting an Array1. It allows to carry the bounds inside the arrays.
    """
    def Assign(self,theOther : HLRAlgo_Array1OfPISeg) -> HLRAlgo_Array1OfPISeg: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeFirst(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_PolyInternalSegment: 
        """
        Variable value access
        """
    def First(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns first element
        """
    def Init(self,theValue : HLRAlgo_PolyInternalSegment) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    def Last(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfPISeg) -> HLRAlgo_Array1OfPISeg: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_PolyInternalSegment) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_PolyInternalSegment: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_PolyInternalSegment: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theAlloc : Any,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfPISeg) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_PolyInternalSegment]: ...
    def __len__(self) -> int: ...
    pass
class HLRAlgo_Array1OfTData():
    """
    The class NCollection_Array1 represents unidimensional arrays of fixed size known at run time. The range of the index is user defined. An array1 can be constructed with a "C array". This functionality is useful to call methods expecting an Array1. It allows to carry the bounds inside the arrays.
    """
    def Assign(self,theOther : HLRAlgo_Array1OfTData) -> HLRAlgo_Array1OfTData: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeFirst(self) -> HLRAlgo_TriangleData: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_TriangleData: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_TriangleData: 
        """
        Variable value access
        """
    def First(self) -> HLRAlgo_TriangleData: 
        """
        Returns first element
        """
    def Init(self,theValue : HLRAlgo_TriangleData) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    def Last(self) -> HLRAlgo_TriangleData: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfTData) -> HLRAlgo_Array1OfTData: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_TriangleData) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_TriangleData: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_TriangleData: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theAlloc : Any,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfTData) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_TriangleData]: ...
    def __len__(self) -> int: ...
    pass
class HLRAlgo_BiPoint():
    @overload
    def Hidden(self) -> bool: ...
    @overload
    def Hidden(self,B : bool) -> None: ...
    def Indices(self) -> Any: ...
    @overload
    def IntLine(self) -> bool: ...
    @overload
    def IntLine(self,B : bool) -> None: ...
    @overload
    def OutLine(self) -> bool: ...
    @overload
    def OutLine(self,B : bool) -> None: ...
    def Points(self) -> Any: ...
    @overload
    def Rg1Line(self) -> bool: ...
    @overload
    def Rg1Line(self,B : bool) -> None: ...
    @overload
    def RgNLine(self) -> bool: ...
    @overload
    def RgNLine(self,B : bool) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,X1 : float,Y1 : float,Z1 : float,X2 : float,Y2 : float,Z2 : float,XT1 : float,YT1 : float,ZT1 : float,XT2 : float,YT2 : float,ZT2 : float,Index : int,reg1 : bool,regn : bool,outl : bool,intl : bool) -> None: ...
    @overload
    def __init__(self,X1 : float,Y1 : float,Z1 : float,X2 : float,Y2 : float,Z2 : float,XT1 : float,YT1 : float,ZT1 : float,XT2 : float,YT2 : float,ZT2 : float,Index : int,flag : int) -> None: ...
    @overload
    def __init__(self,X1 : float,Y1 : float,Z1 : float,X2 : float,Y2 : float,Z2 : float,XT1 : float,YT1 : float,ZT1 : float,XT2 : float,YT2 : float,ZT2 : float,Index : int,i1 : int,i1p1 : int,i1p2 : int,reg1 : bool,regn : bool,outl : bool,intl : bool) -> None: ...
    @overload
    def __init__(self,X1 : float,Y1 : float,Z1 : float,X2 : float,Y2 : float,Z2 : float,XT1 : float,YT1 : float,ZT1 : float,XT2 : float,YT2 : float,ZT2 : float,Index : int,i1 : int,i1p1 : int,i1p2 : int,flag : int) -> None: ...
    @overload
    def __init__(self,X1 : float,Y1 : float,Z1 : float,X2 : float,Y2 : float,Z2 : float,XT1 : float,YT1 : float,ZT1 : float,XT2 : float,YT2 : float,ZT2 : float,Index : int,i1 : int,i1p1 : int,i1p2 : int,i2 : int,i2p1 : int,i2p2 : int,reg1 : bool,regn : bool,outl : bool,intl : bool) -> None: ...
    @overload
    def __init__(self,X1 : float,Y1 : float,Z1 : float,X2 : float,Y2 : float,Z2 : float,XT1 : float,YT1 : float,ZT1 : float,XT2 : float,YT2 : float,ZT2 : float,Index : int,i1 : int,i1p1 : int,i1p2 : int,i2 : int,i2p1 : int,i2p2 : int,flag : int) -> None: ...
    pass
class HLRAlgo_Coincidence():
    """
    The Coincidence class is used in an Interference to store information on the "hiding" edge.
    """
    def Set2D(self,FE : int,Param : float) -> None: ...
    def SetState3D(self,stbef : OCP.TopAbs.TopAbs_State,staft : OCP.TopAbs.TopAbs_State) -> None: ...
    def State3D(self,stbef : OCP.TopAbs.TopAbs_State,staft : OCP.TopAbs.TopAbs_State) -> None: ...
    def Value2D(self) -> tuple[int, float]: ...
    def __init__(self) -> None: ...
    pass
class HLRAlgo_EdgeIterator():
    def Hidden(self,TolStart : float,TolEnd : float) -> tuple[float, float]: 
        """
        Returns the bounds and the tolerances of the current Hidden Interval

        Returns the bounds and the tolerances of the current Hidden Interval
        """
    def InitHidden(self,status : HLRAlgo_EdgeStatus) -> None: ...
    def InitVisible(self,status : HLRAlgo_EdgeStatus) -> None: ...
    def MoreHidden(self) -> bool: ...
    def MoreVisible(self) -> bool: ...
    def NextHidden(self) -> None: ...
    def NextVisible(self) -> None: ...
    def Visible(self,TolStart : float,TolEnd : float) -> tuple[float, float]: 
        """
        Returns the bounds and the tolerances of the current Visible Interval

        Returns the bounds and the tolerances of the current Visible Interval
        """
    def __init__(self) -> None: ...
    pass
class HLRAlgo_EdgeStatus():
    """
    This class describes the Hidden Line status of an Edge. It contains :
    """
    @overload
    def AllHidden(self) -> bool: ...
    @overload
    def AllHidden(self,B : bool) -> None: ...
    @overload
    def AllVisible(self) -> bool: ...
    @overload
    def AllVisible(self,B : bool) -> None: ...
    def Bounds(self,theTolStart : float,theTolEnd : float) -> tuple[float, float]: ...
    def Hide(self,Start : float,TolStart : float,End : float,TolEnd : float,OnFace : bool,OnBoundary : bool) -> None: 
        """
        Hides the interval <Start>, <End> with the tolerances <TolStart>, <TolEnd>. This interval is subtracted from the visible parts. If the hidden part is on ( or under ) the face the flag <OnFace> is True ( or False ). If the hidden part is on ( or inside ) the boundary of the face the flag <OnBoundary> is True ( or False ).
        """
    def HideAll(self) -> None: 
        """
        Hide the whole Edge.
        """
    def Initialize(self,Start : float,TolStart : float,End : float,TolEnd : float) -> None: 
        """
        Initialize an EdgeStatus. Default visible. The Edge is bounded by the interval <Start>, <End> with the tolerances <TolStart>, <TolEnd>.
        """
    def NbVisiblePart(self) -> int: ...
    def ShowAll(self) -> None: 
        """
        Show the whole Edge.
        """
    def VisiblePart(self,Index : int,TolStart : float,TolEnd : float) -> tuple[float, float]: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Start : float,TolStart : float,End : float,TolEnd : float) -> None: ...
    pass
class HLRAlgo_EdgesBlock(OCP.Standard.Standard_Transient):
    """
    An EdgesBlock is a set of Edges. It is used by the DataStructure to structure the Edges.An EdgesBlock is a set of Edges. It is used by the DataStructure to structure the Edges.An EdgesBlock is a set of Edges. It is used by the DataStructure to structure the Edges.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    @overload
    def Double(self,I : int) -> bool: ...
    @overload
    def Double(self,I : int,B : bool) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    @overload
    def Edge(self,I : int,EI : int) -> None: ...
    @overload
    def Edge(self,I : int) -> int: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def Internal(self,I : int) -> bool: ...
    @overload
    def Internal(self,I : int,B : bool) -> None: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    @overload
    def IsoLine(self,I : int) -> bool: ...
    @overload
    def IsoLine(self,I : int,B : bool) -> None: ...
    def MinMax(self) -> Any: ...
    def NbEdges(self) -> int: ...
    @overload
    def Orientation(self,I : int,Or : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def Orientation(self,I : int) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def OutLine(self,I : int) -> bool: ...
    @overload
    def OutLine(self,I : int,B : bool) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateMinMax(self,TotMinMax : Any) -> None: ...
    def __init__(self,NbEdges : int) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_HArray1OfPHDat(HLRAlgo_Array1OfPHDat, OCP.Standard.Standard_Transient):
    def Array1(self) -> HLRAlgo_Array1OfPHDat: ...
    def Assign(self,theOther : HLRAlgo_Array1OfPHDat) -> HLRAlgo_Array1OfPHDat: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeArray1(self) -> HLRAlgo_Array1OfPHDat: ...
    def ChangeFirst(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_PolyHidingData: 
        """
        Variable value access
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def First(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns first element
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self,theValue : HLRAlgo_PolyHidingData) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> HLRAlgo_PolyHidingData: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfPHDat) -> HLRAlgo_Array1OfPHDat: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_PolyHidingData) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_PolyHidingData: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_PolyHidingData: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int,theValue : HLRAlgo_PolyHidingData) -> None: ...
    @overload
    def __init__(self,theBegin : HLRAlgo_PolyHidingData,theLower : int,theUpper : int,arg3 : bool) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfPHDat) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_PolyHidingData]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_HArray1OfPINod(HLRAlgo_Array1OfPINod, OCP.Standard.Standard_Transient):
    def Array1(self) -> HLRAlgo_Array1OfPINod: ...
    def Assign(self,theOther : HLRAlgo_Array1OfPINod) -> HLRAlgo_Array1OfPINod: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeArray1(self) -> HLRAlgo_Array1OfPINod: ...
    def ChangeFirst(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_PolyInternalNode: 
        """
        Variable value access
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def First(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns first element
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self,theValue : HLRAlgo_PolyInternalNode) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> HLRAlgo_PolyInternalNode: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfPINod) -> HLRAlgo_Array1OfPINod: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_PolyInternalNode) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_PolyInternalNode: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_PolyInternalNode: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int,theValue : HLRAlgo_PolyInternalNode) -> None: ...
    @overload
    def __init__(self,theBegin : HLRAlgo_PolyInternalNode,theLower : int,theUpper : int,arg3 : bool) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfPINod) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_PolyInternalNode]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_HArray1OfPISeg(HLRAlgo_Array1OfPISeg, OCP.Standard.Standard_Transient):
    def Array1(self) -> HLRAlgo_Array1OfPISeg: ...
    def Assign(self,theOther : HLRAlgo_Array1OfPISeg) -> HLRAlgo_Array1OfPISeg: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeArray1(self) -> HLRAlgo_Array1OfPISeg: ...
    def ChangeFirst(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_PolyInternalSegment: 
        """
        Variable value access
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def First(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns first element
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self,theValue : HLRAlgo_PolyInternalSegment) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> HLRAlgo_PolyInternalSegment: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfPISeg) -> HLRAlgo_Array1OfPISeg: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_PolyInternalSegment) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_PolyInternalSegment: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_PolyInternalSegment: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int,theValue : HLRAlgo_PolyInternalSegment) -> None: ...
    @overload
    def __init__(self,theBegin : HLRAlgo_PolyInternalSegment,theLower : int,theUpper : int,arg3 : bool) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfPISeg) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_PolyInternalSegment]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_HArray1OfTData(HLRAlgo_Array1OfTData, OCP.Standard.Standard_Transient):
    def Array1(self) -> HLRAlgo_Array1OfTData: ...
    def Assign(self,theOther : HLRAlgo_Array1OfTData) -> HLRAlgo_Array1OfTData: 
        """
        Copies data of theOther array to this. This array should be pre-allocated and have the same length as theOther; otherwise exception Standard_DimensionMismatch is thrown.
        """
    def ChangeArray1(self) -> HLRAlgo_Array1OfTData: ...
    def ChangeFirst(self) -> HLRAlgo_TriangleData: 
        """
        Returns first element
        """
    def ChangeLast(self) -> HLRAlgo_TriangleData: 
        """
        Returns last element
        """
    def ChangeValue(self,theIndex : int) -> HLRAlgo_TriangleData: 
        """
        Variable value access
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def First(self) -> HLRAlgo_TriangleData: 
        """
        Returns first element
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self,theValue : HLRAlgo_TriangleData) -> None: 
        """
        Initialise the items with theValue
        """
    def IsDeletable(self) -> bool: ...
    def IsEmpty(self) -> bool: 
        """
        Return TRUE if array has zero length.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Last(self) -> HLRAlgo_TriangleData: 
        """
        Returns last element
        """
    def Length(self) -> int: 
        """
        Length query (the same)
        """
    def Lower(self) -> int: 
        """
        Lower bound
        """
    def Move(self,theOther : HLRAlgo_Array1OfTData) -> HLRAlgo_Array1OfTData: ...
    def Resize(self,theLower : int,theUpper : int,theToCopyData : bool) -> None: 
        """
        Resizes the array to specified bounds. No re-allocation will be done if length of array does not change, but existing values will not be discarded if theToCopyData set to FALSE.
        """
    def SetValue(self,theIndex : int,theItem : HLRAlgo_TriangleData) -> None: 
        """
        Set value
        """
    def Size(self) -> int: 
        """
        Size query
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateLowerBound(self,theLower : int) -> None: 
        """
        Changes the lowest bound. Do not move data
        """
    def UpdateUpperBound(self,theUpper : int) -> None: 
        """
        Changes the upper bound. Do not move data
        """
    def Upper(self) -> int: 
        """
        Upper bound
        """
    def Value(self,theIndex : int) -> HLRAlgo_TriangleData: 
        """
        Constant value access
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HLRAlgo_TriangleData: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int) -> None: ...
    @overload
    def __init__(self,theLower : int,theUpper : int,theValue : HLRAlgo_TriangleData) -> None: ...
    @overload
    def __init__(self,theBegin : HLRAlgo_TriangleData,theLower : int,theUpper : int,arg3 : bool) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_Array1OfTData) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_TriangleData]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_Interference():
    @overload
    def Boundary(self,B : HLRAlgo_Coincidence) -> None: ...
    @overload
    def Boundary(self) -> HLRAlgo_Coincidence: ...
    @overload
    def BoundaryTransition(self,BTr : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def BoundaryTransition(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    def ChangeBoundary(self) -> HLRAlgo_Coincidence: ...
    def ChangeIntersection(self) -> HLRAlgo_Intersection: ...
    @overload
    def Intersection(self,I : HLRAlgo_Intersection) -> None: ...
    @overload
    def Intersection(self) -> HLRAlgo_Intersection: ...
    @overload
    def Orientation(self,O : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def Orientation(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def Transition(self,Tr : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def Transition(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Inters : HLRAlgo_Intersection,Bound : HLRAlgo_Coincidence,Orient : OCP.TopAbs.TopAbs_Orientation,Trans : OCP.TopAbs.TopAbs_Orientation,BTrans : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    pass
class HLRAlgo_InterferenceList(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : HLRAlgo_Interference) -> HLRAlgo_Interference: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : HLRAlgo_Interference,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : HLRAlgo_InterferenceList) -> None: ...
    def Assign(self,theOther : HLRAlgo_InterferenceList) -> HLRAlgo_InterferenceList: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> HLRAlgo_Interference: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : HLRAlgo_Interference,theIter : Any) -> HLRAlgo_Interference: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : HLRAlgo_InterferenceList,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : HLRAlgo_Interference,theIter : Any) -> HLRAlgo_Interference: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : HLRAlgo_InterferenceList,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> HLRAlgo_Interference: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : HLRAlgo_Interference) -> HLRAlgo_Interference: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : HLRAlgo_InterferenceList) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_InterferenceList) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_Interference]: ...
    def __len__(self) -> int: ...
    pass
class HLRAlgo_Intersection():
    """
    Describes an intersection on an edge to hide. Contains a parameter and a state (ON = on the face, OUT = above the face, IN = under the Face)
    """
    @overload
    def Index(self,Ind : int) -> None: ...
    @overload
    def Index(self) -> int: ...
    @overload
    def Level(self,Lev : int) -> None: ...
    @overload
    def Level(self) -> int: ...
    @overload
    def Orientation(self,Ori : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    @overload
    def Orientation(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def Parameter(self,P : float) -> None: ...
    @overload
    def Parameter(self) -> float: ...
    @overload
    def SegIndex(self,SegInd : int) -> None: ...
    @overload
    def SegIndex(self) -> int: ...
    @overload
    def State(self,S : OCP.TopAbs.TopAbs_State) -> None: ...
    @overload
    def State(self) -> OCP.TopAbs.TopAbs_State: ...
    @overload
    def State(self,St : OCP.TopAbs.TopAbs_State) -> None: ...
    @overload
    def Tolerance(self,T : float) -> None: ...
    @overload
    def Tolerance(self) -> float: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Ori : OCP.TopAbs.TopAbs_Orientation,Lev : int,SegInd : int,Ind : int,P : float,Tol : float,S : OCP.TopAbs.TopAbs_State) -> None: ...
    pass
class HLRAlgo_ListOfBPoint(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : HLRAlgo_BiPoint) -> HLRAlgo_BiPoint: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : HLRAlgo_BiPoint,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : HLRAlgo_ListOfBPoint) -> None: ...
    def Assign(self,theOther : HLRAlgo_ListOfBPoint) -> HLRAlgo_ListOfBPoint: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> HLRAlgo_BiPoint: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : HLRAlgo_BiPoint,theIter : Any) -> HLRAlgo_BiPoint: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : HLRAlgo_ListOfBPoint,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : HLRAlgo_BiPoint,theIter : Any) -> HLRAlgo_BiPoint: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : HLRAlgo_ListOfBPoint,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> HLRAlgo_BiPoint: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : HLRAlgo_BiPoint) -> HLRAlgo_BiPoint: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : HLRAlgo_ListOfBPoint) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : HLRAlgo_ListOfBPoint) -> None: ...
    def __iter__(self) -> Iterator[HLRAlgo_BiPoint]: ...
    def __len__(self) -> int: ...
    pass
class HLRAlgo_PolyAlgo(OCP.Standard.Standard_Transient):
    """
    to remove Hidden lines on Triangulations.to remove Hidden lines on Triangulations.to remove Hidden lines on Triangulations.
    """
    def ChangePolyShell(self) -> Any: ...
    def Clear(self) -> None: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def Hide(self,status : HLRAlgo_EdgeStatus,Index : int,reg1 : bool,regn : bool,outl : bool,intl : bool) -> Any: 
        """
        process hiding between <Pt1> and <Pt2>.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self,theNbShells : int) -> None: ...
    def InitHide(self) -> None: ...
    def InitShow(self) -> None: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MoreHide(self) -> bool: ...
    def MoreShow(self) -> bool: ...
    def NextHide(self) -> None: ...
    def NextShow(self) -> None: ...
    def PolyShell(self) -> Any: ...
    def Show(self,Index : int,reg1 : bool,regn : bool,outl : bool,intl : bool) -> Any: 
        """
        process hiding between <Pt1> and <Pt2>.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self) -> None: 
        """
        Prepare all the data to process the algo.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_PolyData(OCP.Standard.Standard_Transient):
    """
    Data structure of a set of Triangles.Data structure of a set of Triangles.Data structure of a set of Triangles.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    @overload
    def FaceIndex(self,I : int) -> None: ...
    @overload
    def FaceIndex(self) -> int: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HNodes(self,HNodes : OCP.TColgp.TColgp_HArray1OfXYZ) -> None: ...
    def HPHDat(self,HPHDat : HLRAlgo_HArray1OfPHDat) -> None: ...
    def HTData(self,HTData : HLRAlgo_HArray1OfTData) -> None: ...
    def HideByPolyData(self,thePoints : Any,theTriangle : Any,theIndices : Any,HidingShell : bool,status : HLRAlgo_EdgeStatus) -> None: 
        """
        process hiding between <Pt1> and <Pt2>.
        """
    def Hiding(self) -> bool: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Indices(self) -> Any: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Nodes(self) -> OCP.TColgp.TColgp_Array1OfXYZ: ...
    def PHDat(self) -> HLRAlgo_Array1OfPHDat: ...
    def TData(self) -> HLRAlgo_Array1OfTData: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateGlobalMinMax(self,theBox : Any) -> None: ...
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_PolyHidingData():
    """
    Data structure of a set of Hiding Triangles.
    """
    def Indices(self) -> Any: ...
    def Plane(self) -> Any: ...
    def Set(self,Index : int,Minim : int,Maxim : int,A : float,B : float,C : float,D : float) -> None: ...
    def __init__(self) -> None: ...
    pass
class HLRAlgo_PolyInternalData(OCP.Standard.Standard_Transient):
    """
    to Update OutLines.to Update OutLines.to Update OutLines.
    """
    def DecPINod(self) -> None: ...
    def DecPISeg(self) -> None: ...
    def DecTData(self) -> None: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Dump(self) -> None: ...
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IntOutL(self) -> bool: ...
    @overload
    def IntOutL(self,B : bool) -> None: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def NbPINod(self) -> int: ...
    def NbPISeg(self) -> int: ...
    def NbTData(self) -> int: ...
    def PINod(self) -> HLRAlgo_Array1OfPINod: ...
    def PISeg(self) -> HLRAlgo_Array1OfPISeg: ...
    @overload
    def Planar(self) -> bool: ...
    @overload
    def Planar(self,B : bool) -> None: ...
    def TData(self) -> HLRAlgo_Array1OfTData: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateLinks(self,theTData : HLRAlgo_Array1OfTData,thePISeg : HLRAlgo_Array1OfPISeg,thePINod : HLRAlgo_Array1OfPINod) -> None: ...
    def __init__(self,nbNod : int,nbTri : int) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_PolyInternalNode(OCP.Standard.Standard_Transient):
    """
    to Update OutLines.to Update OutLines.to Update OutLines.
    """
    def Data(self) -> Any: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Indices(self) -> Any: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_PolyInternalSegment():
    """
    to Update OutLines.
    """
    def __init__(self) -> None: ...
    @property
    def Conex1(self) -> int:
        """
        :type: int
        """
    @Conex1.setter
    def Conex1(self, arg0: int) -> None:
        pass
    @property
    def Conex2(self) -> int:
        """
        :type: int
        """
    @Conex2.setter
    def Conex2(self, arg0: int) -> None:
        pass
    @property
    def LstSg1(self) -> int:
        """
        :type: int
        """
    @LstSg1.setter
    def LstSg1(self, arg0: int) -> None:
        pass
    @property
    def LstSg2(self) -> int:
        """
        :type: int
        """
    @LstSg2.setter
    def LstSg2(self, arg0: int) -> None:
        pass
    @property
    def NxtSg1(self) -> int:
        """
        :type: int
        """
    @NxtSg1.setter
    def NxtSg1(self, arg0: int) -> None:
        pass
    @property
    def NxtSg2(self) -> int:
        """
        :type: int
        """
    @NxtSg2.setter
    def NxtSg2(self, arg0: int) -> None:
        pass
    pass
class HLRAlgo_PolyMask():
    """
    Members:

      HLRAlgo_PolyMask_EMskOutLin1

      HLRAlgo_PolyMask_EMskOutLin2

      HLRAlgo_PolyMask_EMskOutLin3

      HLRAlgo_PolyMask_EMskGrALin1

      HLRAlgo_PolyMask_EMskGrALin2

      HLRAlgo_PolyMask_EMskGrALin3

      HLRAlgo_PolyMask_FMskBack

      HLRAlgo_PolyMask_FMskSide

      HLRAlgo_PolyMask_FMskHiding

      HLRAlgo_PolyMask_FMskFlat

      HLRAlgo_PolyMask_FMskOnOutL

      HLRAlgo_PolyMask_FMskOrBack

      HLRAlgo_PolyMask_FMskFrBack
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    HLRAlgo_PolyMask_EMskGrALin1: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin1: 8>
    HLRAlgo_PolyMask_EMskGrALin2: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin2: 16>
    HLRAlgo_PolyMask_EMskGrALin3: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin3: 32>
    HLRAlgo_PolyMask_EMskOutLin1: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin1: 1>
    HLRAlgo_PolyMask_EMskOutLin2: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin2: 2>
    HLRAlgo_PolyMask_EMskOutLin3: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin3: 4>
    HLRAlgo_PolyMask_FMskBack: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskBack: 64>
    HLRAlgo_PolyMask_FMskFlat: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFlat: 512>
    HLRAlgo_PolyMask_FMskFrBack: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFrBack: 4096>
    HLRAlgo_PolyMask_FMskHiding: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskHiding: 256>
    HLRAlgo_PolyMask_FMskOnOutL: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOnOutL: 1024>
    HLRAlgo_PolyMask_FMskOrBack: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOrBack: 2048>
    HLRAlgo_PolyMask_FMskSide: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskSide: 128>
    __entries: dict # value = {'HLRAlgo_PolyMask_EMskOutLin1': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin1: 1>, None), 'HLRAlgo_PolyMask_EMskOutLin2': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin2: 2>, None), 'HLRAlgo_PolyMask_EMskOutLin3': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin3: 4>, None), 'HLRAlgo_PolyMask_EMskGrALin1': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin1: 8>, None), 'HLRAlgo_PolyMask_EMskGrALin2': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin2: 16>, None), 'HLRAlgo_PolyMask_EMskGrALin3': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin3: 32>, None), 'HLRAlgo_PolyMask_FMskBack': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskBack: 64>, None), 'HLRAlgo_PolyMask_FMskSide': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskSide: 128>, None), 'HLRAlgo_PolyMask_FMskHiding': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskHiding: 256>, None), 'HLRAlgo_PolyMask_FMskFlat': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFlat: 512>, None), 'HLRAlgo_PolyMask_FMskOnOutL': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOnOutL: 1024>, None), 'HLRAlgo_PolyMask_FMskOrBack': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOrBack: 2048>, None), 'HLRAlgo_PolyMask_FMskFrBack': (<HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFrBack: 4096>, None)}
    __members__: dict # value = {'HLRAlgo_PolyMask_EMskOutLin1': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin1: 1>, 'HLRAlgo_PolyMask_EMskOutLin2': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin2: 2>, 'HLRAlgo_PolyMask_EMskOutLin3': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin3: 4>, 'HLRAlgo_PolyMask_EMskGrALin1': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin1: 8>, 'HLRAlgo_PolyMask_EMskGrALin2': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin2: 16>, 'HLRAlgo_PolyMask_EMskGrALin3': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin3: 32>, 'HLRAlgo_PolyMask_FMskBack': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskBack: 64>, 'HLRAlgo_PolyMask_FMskSide': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskSide: 128>, 'HLRAlgo_PolyMask_FMskHiding': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskHiding: 256>, 'HLRAlgo_PolyMask_FMskFlat': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFlat: 512>, 'HLRAlgo_PolyMask_FMskOnOutL': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOnOutL: 1024>, 'HLRAlgo_PolyMask_FMskOrBack': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOrBack: 2048>, 'HLRAlgo_PolyMask_FMskFrBack': <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFrBack: 4096>}
    pass
class HLRAlgo_PolyShellData(OCP.Standard.Standard_Transient):
    """
    All the PolyData of a ShellAll the PolyData of a ShellAll the PolyData of a Shell
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Edges(self) -> HLRAlgo_ListOfBPoint: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def Hiding(self) -> bool: ...
    def HidingPolyData(self) -> Any: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Indices(self) -> Any: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def PolyData(self) -> Any: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateGlobalMinMax(self,theBox : Any) -> None: ...
    def UpdateHiding(self,nbHiding : int) -> None: ...
    def __init__(self,nbFace : int) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class HLRAlgo_Projector():
    """
    Implements a projector object. To transform and project Points and Planes. This object is designed to be used in the removal of hidden lines and is returned by the Prs3d_Projector::Projector function. You define the projection of the selected shape by calling one of the following functions: - HLRBRep_Algo::Projector, or - HLRBRep_PolyAlgo::Projector The choice depends on the algorithm, which you are using. The parameters of the view are defined at the time of construction of a Prs3d_Projector object.
    """
    def Directions(self,D1 : OCP.gp.gp_Vec2d,D2 : OCP.gp.gp_Vec2d,D3 : OCP.gp.gp_Vec2d) -> None: ...
    def Focus(self) -> float: 
        """
        Returns the focal length.

        Returns the focal length.
        """
    def FullTransformation(self) -> OCP.gp.gp_Trsf: 
        """
        Returns the original transformation.

        Returns the original transformation.
        """
    def InvertedTransformation(self) -> OCP.gp.gp_Trsf: 
        """
        Returns the active inverted transformation.

        Returns the active inverted transformation.
        """
    def Perspective(self) -> bool: 
        """
        Returns True if there is a perspective transformation.

        Returns True if there is a perspective transformation.
        """
    @overload
    def Project(self,P : OCP.gp.gp_Pnt,Pout : OCP.gp.gp_Pnt2d) -> None: 
        """
        Transform and apply perspective if needed.

        Transform and apply perspective if needed.

        Transform and apply perspective if needed.
        """
    @overload
    def Project(self,P : OCP.gp.gp_Pnt,D1 : OCP.gp.gp_Vec,Pout : OCP.gp.gp_Pnt2d,D1out : OCP.gp.gp_Vec2d) -> None: ...
    @overload
    def Project(self,P : OCP.gp.gp_Pnt) -> tuple[float, float, float]: ...
    def Scaled(self,On : bool=False) -> None: 
        """
        to compute with the given scale and translation.
        """
    def Set(self,T : OCP.gp.gp_Trsf,Persp : bool,Focus : float) -> None: ...
    def Shoot(self,X : float,Y : float) -> OCP.gp.gp_Lin: 
        """
        return a line going through the eye towards the 2d point <X,Y>.
        """
    @overload
    def Transform(self,D : OCP.gp.gp_Vec) -> None: ...
    @overload
    def Transform(self,Pnt : OCP.gp.gp_Pnt) -> None: ...
    def Transformation(self) -> OCP.gp.gp_Trsf: 
        """
        Returns the active transformation.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,CS : OCP.gp.gp_Ax2) -> None: ...
    @overload
    def __init__(self,CS : OCP.gp.gp_Ax2,Focus : float) -> None: ...
    @overload
    def __init__(self,T : OCP.gp.gp_Trsf,Persp : bool,Focus : float) -> None: ...
    @overload
    def __init__(self,T : OCP.gp.gp_Trsf,Persp : bool,Focus : float,v1 : OCP.gp.gp_Vec2d,v2 : OCP.gp.gp_Vec2d,v3 : OCP.gp.gp_Vec2d) -> None: ...
    pass
class HLRAlgo_TriangleData():
    """
    Data structure of a triangle.
    """
    def __init__(self) -> None: ...
    @property
    def Flags(self) -> int:
        """
        :type: int
        """
    @Flags.setter
    def Flags(self, arg0: int) -> None:
        pass
    @property
    def Node1(self) -> int:
        """
        :type: int
        """
    @Node1.setter
    def Node1(self, arg0: int) -> None:
        pass
    @property
    def Node2(self) -> int:
        """
        :type: int
        """
    @Node2.setter
    def Node2(self, arg0: int) -> None:
        pass
    @property
    def Node3(self) -> int:
        """
        :type: int
        """
    @Node3.setter
    def Node3(self, arg0: int) -> None:
        pass
    pass
class HLRAlgo_WiresBlock(OCP.Standard.Standard_Transient):
    """
    A WiresBlock is a set of Blocks. It is used by the DataStructure to structure the Edges.A WiresBlock is a set of Blocks. It is used by the DataStructure to structure the Edges.A WiresBlock is a set of Blocks. It is used by the DataStructure to structure the Edges.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MinMax(self) -> Any: ...
    def NbWires(self) -> int: ...
    def Set(self,I : int,W : HLRAlgo_EdgesBlock) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UpdateMinMax(self,theMinMaxes : Any) -> None: ...
    def Wire(self,I : int) -> HLRAlgo_EdgesBlock: ...
    def __init__(self,NbWires : int) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
HLRAlgo_PolyMask_EMskGrALin1: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin1: 8>
HLRAlgo_PolyMask_EMskGrALin2: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin2: 16>
HLRAlgo_PolyMask_EMskGrALin3: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskGrALin3: 32>
HLRAlgo_PolyMask_EMskOutLin1: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin1: 1>
HLRAlgo_PolyMask_EMskOutLin2: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin2: 2>
HLRAlgo_PolyMask_EMskOutLin3: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_EMskOutLin3: 4>
HLRAlgo_PolyMask_FMskBack: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskBack: 64>
HLRAlgo_PolyMask_FMskFlat: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFlat: 512>
HLRAlgo_PolyMask_FMskFrBack: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskFrBack: 4096>
HLRAlgo_PolyMask_FMskHiding: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskHiding: 256>
HLRAlgo_PolyMask_FMskOnOutL: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOnOutL: 1024>
HLRAlgo_PolyMask_FMskOrBack: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskOrBack: 2048>
HLRAlgo_PolyMask_FMskSide: OCP.HLRAlgo.HLRAlgo_PolyMask # value = <HLRAlgo_PolyMask.HLRAlgo_PolyMask_FMskSide: 128>



import OCP.AdvApprox
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import io
import OCP.TColgp
import OCP.TColStd
import OCP.GeomAbs
import OCP.PLib
__all__  = [
"AdvApprox_ApproxAFunction",
"AdvApprox_Cutting",
"AdvApprox_DichoCutting",
"AdvApprox_PrefAndRec",
"AdvApprox_PrefCutting",
"AdvApprox_SimpleApprox"
]
class AdvApprox_ApproxAFunction():
    """
    this approximate a given function
    """
    @staticmethod
    def Approximation_s(TotalDimension : int,TotalNumSS : int,LocalDimension : OCP.TColStd.TColStd_Array1OfInteger,First : float,Last : float,Evaluator : AdvApprox_EvaluatorFunction,CutTool : AdvApprox_Cutting,ContinuityOrder : int,NumMaxCoeffs : int,MaxSegments : int,TolerancesArray : OCP.TColStd.TColStd_Array1OfReal,code_precis : int,NumCoeffPerCurveArray : OCP.TColStd.TColStd_Array1OfInteger,LocalCoefficientArray : OCP.TColStd.TColStd_Array1OfReal,IntervalsArray : OCP.TColStd.TColStd_Array1OfReal,ErrorMaxArray : OCP.TColStd.TColStd_Array1OfReal,AverageErrorArray : OCP.TColStd.TColStd_Array1OfReal) -> tuple[int, int]: ...
    @overload
    def AverageError(self,Dimension : int) -> OCP.TColStd.TColStd_HArray1OfReal: 
        """
        returns the error as is in the algorithms
        """
    @overload
    def AverageError(self,Dimension : int,Index : int) -> float: ...
    def Degree(self) -> int: ...
    def Dump(self,o : io.BytesIO) -> None: 
        """
        display information on approximation.
        """
    def HasResult(self) -> bool: ...
    def IsDone(self) -> bool: ...
    def Knots(self) -> OCP.TColStd.TColStd_HArray1OfReal: ...
    @overload
    def MaxError(self,Dimension : int) -> OCP.TColStd.TColStd_HArray1OfReal: 
        """
        returns the error as is in the algorithms
        """
    @overload
    def MaxError(self,Dimension : int,Index : int) -> float: ...
    def Multiplicities(self) -> OCP.TColStd.TColStd_HArray1OfInteger: ...
    def NbKnots(self) -> int: ...
    def NbPoles(self) -> int: 
        """
        as the name says
        """
    def NumSubSpaces(self,Dimension : int) -> int: ...
    @overload
    def Poles(self) -> OCP.TColgp.TColgp_HArray2OfPnt: 
        """
        -- returns the poles from the algorithms as is

        returns the poles at Index from the 3d subspace

        -- returns the poles from the algorithms as is
        """
    @overload
    def Poles(self,Index : int,P : OCP.TColgp.TColgp_Array1OfPnt) -> None: ...
    @overload
    def Poles1d(self) -> OCP.TColStd.TColStd_HArray2OfReal: 
        """
        returns the poles from the algorithms as is

        returns the poles at Index from the 1d subspace

        returns the poles from the algorithms as is
        """
    @overload
    def Poles1d(self,Index : int,P : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    @overload
    def Poles2d(self) -> OCP.TColgp.TColgp_HArray2OfPnt2d: 
        """
        returns the poles from the algorithms as is

        returns the poles at Index from the 2d subspace

        returns the poles from the algorithms as is
        """
    @overload
    def Poles2d(self,Index : int,P : OCP.TColgp.TColgp_Array1OfPnt2d) -> None: ...
    @overload
    def __init__(self,Num1DSS : int,Num2DSS : int,Num3DSS : int,OneDTol : OCP.TColStd.TColStd_HArray1OfReal,TwoDTol : OCP.TColStd.TColStd_HArray1OfReal,ThreeDTol : OCP.TColStd.TColStd_HArray1OfReal,First : float,Last : float,Continuity : OCP.GeomAbs.GeomAbs_Shape,MaxDeg : int,MaxSeg : int,Func : AdvApprox_EvaluatorFunction) -> None: ...
    @overload
    def __init__(self,Num1DSS : int,Num2DSS : int,Num3DSS : int,OneDTol : OCP.TColStd.TColStd_HArray1OfReal,TwoDTol : OCP.TColStd.TColStd_HArray1OfReal,ThreeDTol : OCP.TColStd.TColStd_HArray1OfReal,First : float,Last : float,Continuity : OCP.GeomAbs.GeomAbs_Shape,MaxDeg : int,MaxSeg : int,Func : AdvApprox_EvaluatorFunction,CutTool : AdvApprox_Cutting) -> None: ...
    pass
class AdvApprox_Cutting():
    """
    to choose the way of cutting in approximation
    """
    def Value(self,a : float,b : float,cuttingvalue : float) -> bool: ...
    pass
class AdvApprox_DichoCutting(AdvApprox_Cutting):
    """
    if Cutting is necessary in [a,b], we cut at (a+b) / 2.
    """
    def Value(self,a : float,b : float,cuttingvalue : float) -> bool: ...
    def __init__(self) -> None: ...
    pass
class AdvApprox_PrefAndRec(AdvApprox_Cutting):
    """
    inherits class Cutting; contains a list of preferential points (pi)i and a list of Recommended points used in cutting management. if Cutting is necessary in [a,b], we cut at the di nearest from (a+b)/2
    """
    def Value(self,a : float,b : float,cuttingvalue : float) -> bool: 
        """
        cuting value is - the recommended point nerest of (a+b)/2 if pi is in ]a,b[ or else - the preferential point nearest of (a+b) / 2 if pi is in ](r*a+b)/(r+1) , (a+r*b)/(r+1)[ where r = Weight - or (a+b)/2 else.
        """
    def __init__(self,RecomendedCut : OCP.TColStd.TColStd_Array1OfReal,PrefferedCut : OCP.TColStd.TColStd_Array1OfReal,Weight : float=5.0) -> None: ...
    pass
class AdvApprox_PrefCutting(AdvApprox_Cutting):
    """
    inherits class Cutting; contains a list of preferential points (di)i if Cutting is necessary in [a,b], we cut at the di nearest from (a+b)/2.
    """
    def Value(self,a : float,b : float,cuttingvalue : float) -> bool: ...
    def __init__(self,CutPnts : OCP.TColStd.TColStd_Array1OfReal) -> None: ...
    pass
class AdvApprox_SimpleApprox():
    """
    Approximate a function on an interval [First,Last] The result is a simple polynomial whose degree is as low as possible to satisfy the required tolerance and the maximum degree. The maximum error and the averrage error resulting from approximating the function by the polynomial are computed
    """
    def AverageError(self,Index : int) -> float: ...
    def Coefficients(self) -> OCP.TColStd.TColStd_HArray1OfReal: 
        """
        returns the coefficients in the Jacobi Base
        """
    def Degree(self) -> int: ...
    def DifTab(self) -> OCP.TColStd.TColStd_HArray1OfReal: ...
    def Dump(self,o : io.BytesIO) -> None: 
        """
        display information on approximation
        """
    def FirstConstr(self) -> OCP.TColStd.TColStd_HArray2OfReal: 
        """
        returns the constraints at First
        """
    def IsDone(self) -> bool: ...
    def LastConstr(self) -> OCP.TColStd.TColStd_HArray2OfReal: 
        """
        returns the constraints at Last
        """
    def MaxError(self,Index : int) -> float: ...
    def Perform(self,LocalDimension : OCP.TColStd.TColStd_Array1OfInteger,LocalTolerancesArray : OCP.TColStd.TColStd_Array1OfReal,First : float,Last : float,MaxDegree : int) -> None: 
        """
        Constructs approximator tool.
        """
    def SomTab(self) -> OCP.TColStd.TColStd_HArray1OfReal: ...
    def __init__(self,TotalDimension : int,TotalNumSS : int,Continuity : OCP.GeomAbs.GeomAbs_Shape,WorkDegree : int,NbGaussPoints : int,JacobiBase : OCP.PLib.PLib_JacobiPolynomial,Func : AdvApprox_EvaluatorFunction) -> None: ...
    pass



import OCP.Geom2dHatch
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import io
import OCP.Geom2dAdaptor
import OCP.gp
import OCP.Geom2dInt
import OCP.HatchGen
import OCP.TopAbs
import OCP.Geom2d
import OCP.IntRes2d
import OCP.Adaptor2d
import OCP.NCollection
__all__  = [
"Geom2dHatch_Classifier",
"Geom2dHatch_Element",
"Geom2dHatch_Elements",
"Geom2dHatch_FClass2dOfClassifier",
"Geom2dHatch_Hatcher",
"Geom2dHatch_Hatching",
"Geom2dHatch_Intersector",
"Geom2dHatch_MapOfElements"
]
class Geom2dHatch_Classifier():
    def Edge(self) -> OCP.Geom2dAdaptor.Geom2dAdaptor_Curve: 
        """
        Returns the Edge used to determine the classification. When the State is ON this is the Edge containing the point.
        """
    def EdgeParameter(self) -> float: 
        """
        Returns the parameter on Edge() used to determine the classification.
        """
    def NoWires(self) -> bool: 
        """
        Returns True if the face contains no wire. The state is IN.
        """
    def Perform(self,F : Geom2dHatch_Elements,P : OCP.gp.gp_Pnt2d,Tol : float) -> None: 
        """
        Classify the Point P with Tolerance <T> on the face described by <F>.
        """
    def Position(self) -> OCP.IntRes2d.IntRes2d_Position: 
        """
        Returns the position of the point on the edge returned by Edge.
        """
    def Rejected(self) -> bool: 
        """
        Returns True when the state was computed by a rejection. The state is OUT.
        """
    def State(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the result of the classification.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,F : Geom2dHatch_Elements,P : OCP.gp.gp_Pnt2d,Tol : float) -> None: ...
    pass
class Geom2dHatch_Element():
    def ChangeCurve(self) -> OCP.Geom2dAdaptor.Geom2dAdaptor_Curve: 
        """
        Returns the curve associated to the element.
        """
    def Curve(self) -> OCP.Geom2dAdaptor.Geom2dAdaptor_Curve: 
        """
        Returns the curve associated to the element.
        """
    @overload
    def Orientation(self,Orientation : OCP.TopAbs.TopAbs_Orientation) -> None: 
        """
        Sets the orientation of the element.

        Returns the orientation of the element.
        """
    @overload
    def Orientation(self) -> OCP.TopAbs.TopAbs_Orientation: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Curve : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,Orientation : OCP.TopAbs.TopAbs_Orientation=TopAbs_Orientation.TopAbs_FORWARD) -> None: ...
    pass
class Geom2dHatch_Elements():
    def Bind(self,K : int,I : Geom2dHatch_Element) -> bool: ...
    def ChangeFind(self,K : int) -> Geom2dHatch_Element: ...
    def CheckPoint(self,P : OCP.gp.gp_Pnt2d) -> bool: ...
    def Clear(self) -> None: ...
    def CurrentEdge(self,E : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,Or : OCP.TopAbs.TopAbs_Orientation) -> None: ...
    def Find(self,K : int) -> Geom2dHatch_Element: ...
    def InitEdges(self) -> None: ...
    def InitWires(self) -> None: ...
    def IsBound(self,K : int) -> bool: ...
    def MoreEdges(self) -> bool: ...
    def MoreWires(self) -> bool: ...
    def NextEdge(self) -> None: ...
    def NextWire(self) -> None: ...
    def OtherSegment(self,P : OCP.gp.gp_Pnt2d,L : OCP.gp.gp_Lin2d,Par : float) -> bool: ...
    def Reject(self,P : OCP.gp.gp_Pnt2d) -> bool: ...
    def RejectEdge(self,L : OCP.gp.gp_Lin2d,Par : float) -> bool: ...
    def RejectWire(self,L : OCP.gp.gp_Lin2d,Par : float) -> bool: ...
    def Segment(self,P : OCP.gp.gp_Pnt2d,L : OCP.gp.gp_Lin2d,Par : float) -> bool: ...
    def UnBind(self,K : int) -> bool: ...
    def __call__(self,K : int) -> Geom2dHatch_Element: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Other : Geom2dHatch_Elements) -> None: ...
    pass
class Geom2dHatch_FClass2dOfClassifier():
    def ClosestIntersection(self) -> int: 
        """
        Returns 0 if the last compared edge had no relevant intersection. Else returns the index of this intersection in the last intersection algorithm.
        """
    def Compare(self,E : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,Or : OCP.TopAbs.TopAbs_Orientation) -> None: 
        """
        Updates the classification process with the edge <E> from the boundary.
        """
    def Intersector(self) -> Geom2dHatch_Intersector: 
        """
        Returns the intersecting algorithm.
        """
    def IsHeadOrEnd(self) -> bool: 
        """
        Returns the Standard_True if the closest intersection point represents head or end of the edge. Returns Standard_False otherwise.
        """
    def Parameter(self) -> float: 
        """
        Returns the current value of the parameter.
        """
    def Reset(self,L : OCP.gp.gp_Lin2d,P : float,Tol : float) -> None: 
        """
        Starts a classification process. The point to classify is the origin of the line <L>. <P> is the original length of the segment on <L> used to compute intersections. <Tol> is the tolerance attached to the line segment in intersections.
        """
    def State(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the current state of the point.
        """
    def __init__(self) -> None: ...
    pass
class Geom2dHatch_Hatcher():
    @overload
    def AddElement(self,Curve : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,Orientation : OCP.TopAbs.TopAbs_Orientation=TopAbs_Orientation.TopAbs_FORWARD) -> int: 
        """
        Adds an element to the hatcher and returns its index.

        Adds an element to the hatcher and returns its index.
        """
    @overload
    def AddElement(self,Curve : OCP.Geom2d.Geom2d_Curve,Orientation : OCP.TopAbs.TopAbs_Orientation=TopAbs_Orientation.TopAbs_FORWARD) -> int: ...
    def AddHatching(self,Curve : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve) -> int: 
        """
        Adds a hatching to the hatcher and returns its index.
        """
    def ChangeIntersector(self) -> Geom2dHatch_Intersector: 
        """
        Returns the associated intersector.

        Returns the associated intersector.
        """
    def Clear(self) -> None: 
        """
        Removes all the hatchings and all the elements.

        Removes all the hatchings and all the elements.
        """
    def ClrElements(self) -> None: 
        """
        Removes all the elements from the hatcher.
        """
    def ClrHatchings(self) -> None: 
        """
        Removes all the hatchings from the hatcher.
        """
    @overload
    def ComputeDomains(self) -> None: 
        """
        Computes the domains of all the hatchings.

        Computes the domains of the IndH-th hatching.
        """
    @overload
    def ComputeDomains(self,IndH : int) -> None: ...
    @overload
    def Confusion2d(self,Confusion : float) -> None: 
        """
        Sets the confusion tolerance.

        Returns the 2d confusion tolerance, i.e. the value under which two points are considered identical in the parametric space of the hatching.

        Returns the 2d confusion tolerance, i.e. the value under which two points are considered identical in the parametric space of the hatching.
        """
    @overload
    def Confusion2d(self) -> float: ...
    @overload
    def Confusion3d(self,Confusion : float) -> None: 
        """
        Sets the confusion tolerance.

        Returns the 3d confusion tolerance, i.e. the value under which two points are considered identical in the 3d space of the hatching.

        Returns the 3d confusion tolerance, i.e. the value under which two points are considered identical in the 3d space of the hatching.
        """
    @overload
    def Confusion3d(self) -> float: ...
    def Domain(self,IndH : int,IDom : int) -> OCP.HatchGen.HatchGen_Domain: 
        """
        Returns the IDom-th domain of the IndH-th hatching.
        """
    def Dump(self) -> None: 
        """
        Dump the hatcher.
        """
    def ElementCurve(self,IndE : int) -> OCP.Geom2dAdaptor.Geom2dAdaptor_Curve: 
        """
        Returns the curve associated to the IndE-th element.

        Returns the curve associated to the IndE-th element.
        """
    def HatchingCurve(self,IndH : int) -> OCP.Geom2dAdaptor.Geom2dAdaptor_Curve: 
        """
        Returns the curve associated to the IndH-th hatching.

        Returns the curve associated to the IndH-th hatching.
        """
    @overload
    def Intersector(self,Intersector : Geom2dHatch_Intersector) -> None: 
        """
        Sets the associated intersector.

        Returns the associated intersector.

        Returns the associated intersector.
        """
    @overload
    def Intersector(self) -> Geom2dHatch_Intersector: ...
    def IsDone(self,IndH : int) -> bool: 
        """
        Returns the fact that the domains were computed for the IndH-th hatching.

        Returns the fact that the domains were computed for the IndH-th hatching.
        """
    @overload
    def KeepPoints(self,Keep : bool) -> None: 
        """
        Sets the above flag.

        Returns the flag about the points consideration.

        Returns the flag about the points consideration.
        """
    @overload
    def KeepPoints(self) -> bool: ...
    @overload
    def KeepSegments(self,Keep : bool) -> None: 
        """
        Sets the above flag.

        Returns the flag about the segments consideration.

        Returns the flag about the segments consideration.
        """
    @overload
    def KeepSegments(self) -> bool: ...
    def NbDomains(self,IndH : int) -> int: 
        """
        Returns the number of domains of the IndH-th hatching. Only ONE "INFINITE" domain means that the hatching is fully included in the contour defined by the elements.

        Returns the number of domains of the IndH-th hatching. Only ONE "INFINITE" domain means that the hatching is fully included in the contour defined by the elements.
        """
    def NbPoints(self,IndH : int) -> int: 
        """
        Returns the number of intersection points of the IndH-th hatching.

        Returns the number of intersection points of the IndH-th hatching.
        """
    def Point(self,IndH : int,IndP : int) -> OCP.HatchGen.HatchGen_PointOnHatching: 
        """
        Returns the IndP-th intersection point of the IndH-th hatching.

        Returns the IndP-th intersection point of the IndH-th hatching.
        """
    def RemElement(self,IndE : int) -> None: 
        """
        Removes the IndE-th element from the hatcher.
        """
    def RemHatching(self,IndH : int) -> None: 
        """
        Removes the IndH-th hatching from the hatcher.
        """
    def Status(self,IndH : int) -> OCP.HatchGen.HatchGen_ErrorStatus: 
        """
        Returns the status about the IndH-th hatching.

        Returns the status about the IndH-th hatching.
        """
    @overload
    def Trim(self) -> None: 
        """
        Trims all the hatchings of the hatcher by all the elements of the hatcher.

        Adds a hatching to the hatcher and trims it by the elements already given and returns its index.

        Trims the IndH-th hatching by the elements already given.
        """
    @overload
    def Trim(self,Curve : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve) -> int: ...
    @overload
    def Trim(self,IndH : int) -> None: ...
    def TrimDone(self,IndH : int) -> bool: 
        """
        Returns the fact that the intersections were computed for the IndH-th hatching.

        Returns the fact that the intersections were computed for the IndH-th hatching.
        """
    def TrimFailed(self,IndH : int) -> bool: 
        """
        Returns the fact that the intersections failed for the IndH-th hatching.

        Returns the fact that the intersections failed for the IndH-th hatching.
        """
    def __init__(self,Intersector : Geom2dHatch_Intersector,Confusion2d : float,Confusion3d : float,KeepPnt : bool=False,KeepSeg : bool=False) -> None: ...
    pass
class Geom2dHatch_Hatching():
    def AddDomain(self,Domain : OCP.HatchGen.HatchGen_Domain) -> None: 
        """
        Adds a domain to the hatching.
        """
    def AddPoint(self,Point : OCP.HatchGen.HatchGen_PointOnHatching,Confusion : float) -> None: 
        """
        Adds an intersection point to the hatching.
        """
    def ChangeCurve(self) -> OCP.Geom2dAdaptor.Geom2dAdaptor_Curve: 
        """
        Returns the curve associated to the hatching.
        """
    def ChangePoint(self,Index : int) -> OCP.HatchGen.HatchGen_PointOnHatching: 
        """
        Returns the Index-th intersection point of the hatching. The exception OutOfRange is raised if Index < 1 or Index > NbPoints.
        """
    def ClassificationPoint(self) -> OCP.gp.gp_Pnt2d: 
        """
        Returns a point on the curve. This point will be used for the classification.
        """
    def ClrDomains(self) -> None: 
        """
        Removes all the domains of the hatching.
        """
    def ClrPoints(self) -> None: 
        """
        Removes all the intersection points of the hatching.
        """
    def Curve(self) -> OCP.Geom2dAdaptor.Geom2dAdaptor_Curve: 
        """
        Returns the curve associated to the hatching.
        """
    def Domain(self,Index : int) -> OCP.HatchGen.HatchGen_Domain: 
        """
        Returns the Index-th domain of the hatching. The exception OutOfRange is raised if Index < 1 or Index > NbDomains.
        """
    @overload
    def IsDone(self,Flag : bool) -> None: 
        """
        Sets the flag about the domains computation to the given value.

        Returns the flag about the domains computation.
        """
    @overload
    def IsDone(self) -> bool: ...
    def NbDomains(self) -> int: 
        """
        Returns the number of domains of the hatching.
        """
    def NbPoints(self) -> int: 
        """
        Returns the number of intersection points of the hatching.
        """
    def Point(self,Index : int) -> OCP.HatchGen.HatchGen_PointOnHatching: 
        """
        Returns the Index-th intersection point of the hatching. The exception OutOfRange is raised if Index < 1 or Index > NbPoints.
        """
    def RemDomain(self,Index : int) -> None: 
        """
        Removes the Index-th domain of the hatching. The exception OutOfRange is raised if Index < 1 or Index > NbDomains.
        """
    def RemPoint(self,Index : int) -> None: 
        """
        Removes the Index-th intersection point of the hatching. The exception OutOfRange is raised if Index < 1 or Index > NbPoints.
        """
    @overload
    def Status(self,theStatus : OCP.HatchGen.HatchGen_ErrorStatus) -> None: 
        """
        Sets the error status.

        Returns the error status.
        """
    @overload
    def Status(self) -> OCP.HatchGen.HatchGen_ErrorStatus: ...
    @overload
    def TrimDone(self,Flag : bool) -> None: 
        """
        Sets the flag about the trimming computations to the given value.

        Returns the flag about the trimming computations.
        """
    @overload
    def TrimDone(self) -> bool: ...
    @overload
    def TrimFailed(self,Flag : bool) -> None: 
        """
        Sets the flag about the trimming failure to the given value.

        Returns the flag about the trimming failure.
        """
    @overload
    def TrimFailed(self) -> bool: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Curve : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve) -> None: ...
    pass
class Geom2dHatch_Intersector(OCP.Geom2dInt.Geom2dInt_GInter, OCP.IntRes2d.IntRes2d_Intersection):
    def ComputeDomain(self,C1 : OCP.Adaptor2d.Adaptor2d_Curve2d,TolDomain : float) -> OCP.IntRes2d.IntRes2d_Domain: 
        """
        Create a domain from a curve
        """
    def ConfusionTolerance(self) -> float: 
        """
        Returns the confusion tolerance of the intersector.

        Returns the confusion tolerance of the intersector.
        """
    def GetMinNbSamples(self) -> int: ...
    def Intersect(self,C1 : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,C2 : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve) -> None: 
        """
        Intersects the curves C1 and C2. The results are retrieved by the usual methods described in IntRes2d_Intersection. Creates an intersector.

        Intersects the curves C1 and C2. The results are retrieved by the usual methods described in IntRes2d_Intersection. Creates an intersector.
        """
    def IsDone(self) -> bool: 
        """
        returns TRUE when the computation was successful.

        returns TRUE when the computation was successful.
        """
    def IsEmpty(self) -> bool: 
        """
        Returns TRUE if there is no intersection between the given arguments. The exception NotDone is raised if IsDone returns FALSE.

        Returns TRUE if there is no intersection between the given arguments. The exception NotDone is raised if IsDone returns FALSE.
        """
    def LocalGeometry(self,E : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve,U : float,T : OCP.gp.gp_Dir2d,N : OCP.gp.gp_Dir2d) -> tuple[float]: 
        """
        Returns in <T>, <N> and <C> the tangent, normal and curvature of the edge <E> at parameter value <U>.
        """
    def NbPoints(self) -> int: 
        """
        This function returns the number of intersection points between the 2 curves. The exception NotDone is raised if IsDone returns FALSE.

        This function returns the number of intersection points between the 2 curves. The exception NotDone is raised if IsDone returns FALSE.
        """
    def NbSegments(self) -> int: 
        """
        This function returns the number of intersection segments between the two curves. The exception NotDone is raised if IsDone returns FALSE.

        This function returns the number of intersection segments between the two curves. The exception NotDone is raised if IsDone returns FALSE.
        """
    def Perform(self,L : OCP.gp.gp_Lin2d,P : float,Tol : float,E : OCP.Geom2dAdaptor.Geom2dAdaptor_Curve) -> None: 
        """
        Performs the intersection between the 2d line segment (<L>, <P>) and the Curve <E>. The line segment is the part of the 2d line <L> of parameter range [0, <P>] (P is positive and can be RealLast()). Tol is the Tolerance on the segment. The order is relevant, the first argument is the segment, the second the Edge.
        """
    def Point(self,N : int) -> OCP.IntRes2d.IntRes2d_IntersectionPoint: 
        """
        This function returns the intersection point of range N; The exception NotDone is raised if IsDone returns FALSE. The exception OutOfRange is raised if (N <= 0) or (N > NbPoints).

        This function returns the intersection point of range N; The exception NotDone is raised if IsDone returns FALSE. The exception OutOfRange is raised if (N <= 0) or (N > NbPoints).
        """
    def Segment(self,N : int) -> OCP.IntRes2d.IntRes2d_IntersectionSegment: 
        """
        This function returns the intersection segment of range N; The exception NotDone is raised if IsDone returns FALSE. The exception OutOfRange is raised if (N <= 0) or (N > NbPoints).

        This function returns the intersection segment of range N; The exception NotDone is raised if IsDone returns FALSE. The exception OutOfRange is raised if (N <= 0) or (N > NbPoints).
        """
    def SetConfusionTolerance(self,Confusion : float) -> None: 
        """
        Sets the confusion tolerance of the intersector.

        Sets the confusion tolerance of the intersector.
        """
    def SetMinNbSamples(self,theMinNbSamples : int) -> None: 
        """
        Set / get minimum number of points in polygon intersection.
        """
    @overload
    def SetReversedParameters(self,Reverseflag : bool) -> None: ...
    @overload
    def SetReversedParameters(self,flag : bool) -> None: ...
    def SetTangencyTolerance(self,Tangency : float) -> None: 
        """
        Sets the tangency tolerance of the intersector.

        Sets the tangency tolerance of the intersector.
        """
    def TangencyTolerance(self) -> float: 
        """
        Returns the tangency tolerance of the intersector.

        Returns the tangency tolerance of the intersector.
        """
    @overload
    def __init__(self,Confusion : float,Tangency : float) -> None: ...
    @overload
    def __init__(self) -> None: ...
    pass
class Geom2dHatch_MapOfElements(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: The DataMap is a Map to store keys with associated Items. See Map from NCollection for a discussion about the number of buckets.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : Geom2dHatch_MapOfElements) -> Geom2dHatch_MapOfElements: 
        """
        Assignment. This method does not change the internal allocator.
        """
    def Bind(self,theKey : int,theItem : Geom2dHatch_Element) -> bool: 
        """
        Bind binds Item to Key in map.
        """
    def Bound(self,theKey : int,theItem : Geom2dHatch_Element) -> Geom2dHatch_Element: 
        """
        Bound binds Item to Key in map.
        """
    def ChangeFind(self,theKey : int) -> Geom2dHatch_Element: 
        """
        ChangeFind returns mofifiable Item by Key. Raises if Key was not bound
        """
    def ChangeSeek(self,theKey : int) -> Geom2dHatch_Element: 
        """
        ChangeSeek returns modifiable pointer to Item by Key. Returns NULL is Key was not bound.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    def Exchange(self,theOther : Geom2dHatch_MapOfElements) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    @overload
    def Find(self,theKey : int) -> Geom2dHatch_Element: 
        """
        Find returns the Item for Key. Raises if Key was not bound

        Find Item for key with copying.
        """
    @overload
    def Find(self,theKey : int,theValue : Geom2dHatch_Element) -> bool: ...
    def IsBound(self,theKey : int) -> bool: 
        """
        IsBound
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,N : int) -> None: 
        """
        ReSize
        """
    def Seek(self,theKey : int) -> Geom2dHatch_Element: 
        """
        Seek returns pointer to Item by Key. Returns NULL is Key was not bound.
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def UnBind(self,theKey : int) -> bool: 
        """
        UnBind removes Item Key pair from map
        """
    def __call__(self,theKey : int) -> Geom2dHatch_Element: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : Geom2dHatch_MapOfElements) -> None: ...
    def __iter__(self) -> Iterator[Geom2dHatch_Element]: ...
    def __len__(self) -> int: ...
    pass
